BM.R2CV <- function(mod_data, mod_size, folds, repetitions, rob=T, n_cores = detectCores() / 2){
  
  subsets_var_id <- matrix(t(combn(2:ncol(mod_data), mod_size)), ncol = mod_size, dimnames = list(NULL, paste("V", c(1:mod_size), sep = ""))) 
  
  n_models <- nrow(subsets_var_id)
  
  n_obs <- nrow(mod_data)
  
  
  fit_model <-  if(rob == T) {function(formula, data) regr(formula, data, robust = T)
    
  } else if (rob == F) {function(formula, data) regr(formula, data, robust = F, family = "gaussian")}  
  
  cluster1 <- makeCluster(n_cores)
  
  clusterSetRNGStream(cluster1, .Random.seed)
  
  on.exit(stopCluster(cluster1))
  
  clusterExport(cluster1, c("regr", "predict.regr", "nainf.exclude"), envir = .GlobalEnv)
  
  clusterExport(cluster1, c("mod_data", "n_models", "subsets_var_id", "fit_model"), envir = environment())
  
#first rank all models by adj.r.squared  
  adj.r.squared <- matrix(data = NA, nrow = n_models, ncol = 1)
  
  colnames(adj.r.squared ) <- "adj.r.squared "
  
  set.seed(1)
  if(n_cores>1){
    adj.r.squared[] <- t(parSapply(cluster1, 1:n_models, function(o) {
    
    
    model <- fit_model(formula(mod_data[, c(1, subsets_var_id[o, ])]), mod_data[, c(1, subsets_var_id[o, ])])
    if("adj.r.squared"%in%names(model)){model$adj.r.squared}else{NA}
    
    
    
  }))
  }else{
    adj.r.squared[] <- t(sapply(1:n_models, function(o) {
      
      
      model <- fit_model(formula(mod_data[, c(1, subsets_var_id[o, ])]), mod_data[, c(1, subsets_var_id[o, ])])
      if("adj.r.squared"%in%names(model)){model$adj.r.squared}else{NA}
      
      
      
    }))
}
  
  subsets_var_names <- apply(subsets_var_id, 2, function(x) colnames(mod_data)[x])
  
  model_compil <- data.frame(subsets_var_names, adj.r.squared, stringsAsFactors = F)
  
  model_compil_ranked <- model_compil[order(adj.r.squared, decreasing = T), ]


  
#calculate cv_rmse for the first 100 models (or all models) with highest adj.r.squared  
  n_mod_to_rank <- min(n_models,100)
  
  set.seed(1)
  folds_ID <- lapply(1:repetitions, function(x) {
    
    id <- c(1:n_obs)[order(runif(n_obs))]
    
    k <- as.integer(n_obs * c(1:(folds - 1)) / folds)
    
    k <- matrix(c(0, rep(k, each = 2), n_obs), ncol = 2, byrow = T) 
    
    k[, 1] <- k[, 1] + 1
    
    lapply(1:folds, function(y) { 
      
      list(train = id[!(c(1:n_obs) %in% c(k[y, 1]:k[y, 2]))], test = id[c(k[y, 1]:k[y, 2])])
      
    })
    
  })  
  
  
  cv_rmse_reps <- matrix(data = NA, nrow = n_mod_to_rank, ncol = repetitions)#n_mod_to_rank
  
  colnames(cv_rmse_reps) <- paste("cv_rmse_rep", c(1:repetitions), sep = "_")
  
  set.seed(1)
  
  #browser()#debugging
  
  cv_rmse_reps[] <- t(sapply( 1:n_mod_to_rank, function(o) {
    
    sapply(1:repetitions, function(r) {
    
      
      mean(sapply(1:folds, function(i) {
        
        
        model <- lmrob(formula(mod_data[folds_ID[[r]][[i]]$train, unlist(c(colnames(mod_data)[1], model_compil_ranked[o,1:mod_size]))]),
                           mod_data[folds_ID[[r]][[i]]$train, unlist(c(colnames(mod_data)[1], model_compil_ranked[o,1:mod_size]))])
        
        model_pred <- predict(model, newdata = mod_data[folds_ID[[r]][[i]]$test, unlist(c(colnames(mod_data)[1],model_compil_ranked[o,1:mod_size]))])
        
        sqrt(mean((mod_data[folds_ID[[r]][[i]]$test, 1] - model_pred) ^ 2, na.rm = T))
        
        #print(paste("o=",o,", ","r=",r,", ","i=",i, sep = ""))#for debugging
        
      }))
      
    })
    
  }))

  
  cv_rmse_mean <- apply(cv_rmse_reps, 1, mean, na.rm=TRUE)

#rank the first 100 models (or all models)  by cv_rmse_mean
  model_compil_select <- cbind(model_compil_ranked[1:n_mod_to_rank,],cv_rmse_mean, cv_rmse_reps)
  
  model_compil_select <- model_compil_select[1:n_mod_to_rank,][order(cv_rmse_mean, decreasing = F), ]
 

#select models that have cv_rmse_mean higher than the averaged value among the 100 models and rank them again by adj.r.squared 
  if(mod_size==1) k <- n_models else
    k <- 50

  model_compil_select[1:k,] <- model_compil_select[1:k,][order(model_compil_select[1:k,]$adj.r.squared, decreasing = T), ]

  model_output <- model_compil_select
  

  return(model_output)
  
}
