# Load packages, functions, and prepare the data 
#install packages
install.packages("quantreg")
install.packages("leaps")
install.packages("regr0", repos="http://R-Forge.R-project.org")
install.packages("soiltexture")
install.packages("spatstat")
install.packages("ggcorrplot")

library("robustbase")
library("regr0")
library("spatstat")
library("ggcorrplot")
library("soiltexture")

#load functions by open and run:
#bestmodels_R2CV.R   
#bestmodels_R2CV_details.R   
#calcLMG (by Michael Simmler).R

survey <- read.table("field survey_data.csv",header=TRUE,sep=",", skip=2)  

#Parameters sets for grain As models
#--------------------------------------------------------------
As.data <- survey

resp_var <- c("As_RT")

As.set.1_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",    "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "As_ST"
)

As.set.2_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Al_AscCit",    "P_AscCit",    "S_AscCit",
  "Mn_AscCit",    "Fe_AscCit",   "Co_AscCit",   "Ni_AscCit",    "Cu_AscCit",
  "As_AscCit"
)

As.set.3_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "OC_Diss",    "N_Diss",    "Al_Diss",    "Si_Diss",   "P_Diss",    "S_Diss",
  "Mn_Diss",    "Fe_Diss",   "Co_Diss",    "Ni_Diss",    
  "As_Diss"
)

As.set.4_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",    "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "As_ST", 
  "Al_AscCit",    "P_AscCit",    "S_AscCit",
  "Mn_AscCit",    "Fe_AscCit",   "Co_AscCit",   "Ni_AscCit",    "Cu_AscCit",
  "As_AscCit",
  "OC_Diss",    "N_Diss",    "Al_Diss",    "Si_Diss",   "P_Diss",    "S_Diss",
  "Mn_Diss",    "Fe_Diss",   "Co_Diss",    "Ni_Diss",    
  "As_Diss"
)
#--------------------------------------------------------------

#fitting best models
#--------------------------------------------------------------
#set.1
As.set.1 <- As.data[, c(resp_var,As.set.1_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

As.set.1[, !(colnames(As.set.1) %in% exclude_from_log10)] <- log10(As.set.1[, !(colnames(As.set.1) %in% exclude_from_log10)])

colnames(As.set.1)[!colnames(As.set.1) %in% exclude_from_log10] <- paste("log10_", colnames(As.set.1[, !(colnames(As.set.1) %in% exclude_from_log10)]), sep = "")

As.set.1[As.set.1 == "-Inf"] <- NA
As.set.1[As.set.1 == "NaN"] <- NA

set.seed(1)

As_RT.set.1.V1.BM <- regr(log10_As_RT ~ log10_As_ST, As.set.1, robust = T)
As_RT.set.1.V1.pred <- predict(As_RT.set.1.V1.BM, newdata = As.set.1)

As_RT.set.1.V2.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_ST + log10_Cu_ST, mod_data = As.set.1, rob = T, rela = T)
As_RT.set.1.V2.pred <- predict(As_RT.set.1.V2.BM$model, newdata = As.set.1)

As_RT.set.1.V3.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_ST + log10_Cu_ST + log10_Fe_ST, mod_data = As.set.1, rob = T, rela = T)
As_RT.set.1.V3.pred <- predict(As_RT.set.1.V3.BM$model, newdata = As.set.1)

#As_RT.set.1.V4.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_ST + log10_Cu_ST + log10_Fe_ST + log10_Ca_ST, mod_data = As.set.1, rob = T, rela = T)
#As_RT.set.1.V4.pred <- predict(As_RT.set.1.V4.BM$model, newdata = As.set.1)

#set.2
As.set.2 <- As.data[, c(resp_var,As.set.2_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

As.set.2[, !(colnames(As.set.2) %in% exclude_from_log10)] <- log10(As.set.2[, !(colnames(As.set.2) %in% exclude_from_log10)])

colnames(As.set.2)[!colnames(As.set.2) %in% exclude_from_log10] <- paste("log10_", colnames(As.set.2[, !(colnames(As.set.2) %in% exclude_from_log10)]), sep = "")

As.set.2[As.set.2 == "-Inf"] <- NA
As.set.2[As.set.2 == "NaN"] <- NA

set.seed(1)

As_RT.set.2.V1.BM <- regr(log10_As_RT ~ log10_As_AscCit, As.set.2, robust = T)
As_RT.set.2.V1.pred <- predict(As_RT.set.2.V1.BM, newdata = As.set.2)

As_RT.set.2.V2.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_AscCit + log10_S_AscCit, mod_data = As.set.2, rob = T, rela = T)
As_RT.set.2.V2.pred <- predict(As_RT.set.2.V2.BM$model, newdata = As.set.2)

As_RT.set.2.V3.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_AscCit + log10_S_AscCit + log10_sand, mod_data = As.set.2, rob = T, rela = T)
As_RT.set.2.V3.pred <- predict(As_RT.set.2.V3.BM$model, newdata = As.set.2)

#As_RT.set.2.V4.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_AscCit + log10_S_AscCit + log10_Mn_AscCit + log10_Co_AscCit, mod_data = As.set.2, rob = T, rela = T)
#As_RT.set.2.V4.pred <- predict(As_RT.set.2.V4.BM$model, newdata = As.set.2)

#set.3
As.set.3 <- As.data[, c(resp_var,As.set.3_var)] 
#As.set.3 <- As.data.reduced_S[, c(resp_var,As.set.3_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

As.set.3[, !(colnames(As.set.3) %in% exclude_from_log10)] <- log10(As.set.3[, !(colnames(As.set.3) %in% exclude_from_log10)])

colnames(As.set.3)[!colnames(As.set.3) %in% exclude_from_log10] <- paste("log10_", colnames(As.set.3[, !(colnames(As.set.3) %in% exclude_from_log10)]), sep = "")

As.set.3[As.set.3 == "-Inf"] <- NA
As.set.3[As.set.3 == "NaN"] <- NA

set.seed(1)

As_RT.set.3.V1.BM <- regr(log10_As_RT ~ log10_As_Diss, As.set.3, robust = T)
As_RT.set.3.V1.pred <- predict(As_RT.set.3.V1.BM, newdata = As.set.3)

As_RT.set.3.V2.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_Diss + log10_S_Diss, mod_data = As.set.3, rob = T, rela = T)
As_RT.set.3.V2.pred <- predict(As_RT.set.3.V2.BM$model, newdata = As.set.3)

As_RT.set.3.V3.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_Diss + log10_S_Diss + log10_clay, mod_data = As.set.3, rob = T, rela = T)
As_RT.set.3.V3.pred <- predict(As_RT.set.3.V3.BM$model, newdata = As.set.3)

#As_RT.set.3.V4.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_Diss + log10_S_Diss + log10_clay + log10_Mn_Diss, mod_data = As.set.3, rob = T, rela = T)
#As_RT.set.3.V4.pred <- predict(As_RT.set.3.V4.BM$model, newdata = As.set.3)

#set.4
As.set.4 <- As.data[, c(resp_var,As.set.4_var)] 
#As.set.4 <- As.data.reduced_S[, c(resp_var,As.set.4_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

As.set.4[, !(colnames(As.set.4) %in% exclude_from_log10)] <- log10(As.set.4[, !(colnames(As.set.4) %in% exclude_from_log10)])

colnames(As.set.4)[!colnames(As.set.4) %in% exclude_from_log10] <- paste("log10_", colnames(As.set.4[, !(colnames(As.set.4) %in% exclude_from_log10)]), sep = "")

As.set.4[As.set.4 == "-Inf"] <- NA
As.set.4[As.set.4 == "NaN"] <- NA

set.seed(1)

As_RT.set.4.V1.BM <- regr(log10_As_RT ~ log10_As_AscCit, As.set.4, robust = T)
As_RT.set.4.V1.pred <- predict(As_RT.set.4.V1.BM, newdata = As.set.4)

As_RT.set.4.V2.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_AscCit + log10_S_Diss, mod_data = As.set.4, rob = T, rela = T)
As_RT.set.4.V2.pred <- predict(As_RT.set.4.V2.BM$model, newdata = As.set.4)

As_RT.set.4.V3.BM <- calcLMG(mod_form = log10_As_RT ~ log10_As_AscCit + log10_S_Diss + log10_clay, mod_data = As.set.4, rob = T, rela = T)
As_RT.set.4.V3.pred <- predict(As_RT.set.4.V3.BM$model, newdata = As.set.4)
#--------------------------------------------------------------

#plot best As models: 4 sets of 1,2,3-variable models
pdf("Figure 2 (main part)_best grain As models.pdf", 8, 6)
par(mfrow=c(3,4), mar=c(2.5,2.5,2,1))
#--------------------------------------------------------------
#labelsX=parse(text=paste(10, "^", seq(1.6,2.6, 0.4),sep=""))
#par(mfrow=c(3,3), mar=c(2.5,2.5,2,1))
par(mfrow=c(3,4), mar=c(2.5,2.5,2,1))
labelsX=parse(text=paste(10, "^", seq(1.5,2.7, 0.5),sep=""))
labelsY=labelsX
orange.scale <- colorRampPalette( c( "white","orange" ))(100)
green.scale <- colorRampPalette( c( "white","darkgreen" ))(100)
#--------------------------------------------------------------
#V1
#--------------------------------------------------------------
plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.1.V1.pred, As.set.1[,"log10_As_RT"], col="black",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(As_RT.set.1.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_ST", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.1.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.2.V1.pred, As.set.2[,"log10_As_RT"], col="brown",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(As_RT.set.2.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.2.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.3.V1.pred, As.set.3[,"log10_As_RT"], col="darkblue",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(As_RT.set.3.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_Diss", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.3.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.4.V1.pred, As.set.4[,"log10_As_RT"], col="darkgoldenrod",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(As_RT.set.4.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.4.V1.BM$adj.r.squared, digits=1, nsmall=2))))
#--------------------------------------------------------------
#V2
#--------------------------------------------------------------
plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.1.V2.pred, As.set.1[,"log10_As_RT"], col="black",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.1.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.1.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.1.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.1.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_ST", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cu_ST", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.1.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.2.V2.pred, As.set.2[,"log10_As_RT"], col="brown",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.2.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.2.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.2.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.2.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_AscCit", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.2.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.3.V2.pred, As.set.3[,"log10_As_RT"], col="darkblue",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.3.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.3.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.3.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.3.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_Diss", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_Diss", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.3.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.4.V2.pred, As.set.4[,"log10_As_RT"], col="darkgoldenrod",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.4.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.4.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.4.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.4.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_Diss", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.4.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))
#--------------------------------------------------------------
#V3
#--------------------------------------------------------------
plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.1.V3.pred, As.set.1[,"log10_As_RT"], col="black",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.1.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*As_RT.set.1.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], lim[1]+(lim[2]-lim[1])*2/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.1.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.1.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.1.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.1.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "As_ST", xpd=T)
text(lim[1]+(lim[2]-lim[1])*4/8, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cu_ST", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Fe_ST", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.1.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.2.V3.pred, As.set.2[,"log10_As_RT"], col="brown",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.2.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*As_RT.set.2.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.2.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.2.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.2.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.2.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_AscCit", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "sand", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.2.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.3.V3.pred, As.set.3[,"log10_As_RT"], col="darkblue",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.3.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*As_RT.set.3.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.3.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.3.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.3.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.3.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "As_Diss", xpd=T)
text(lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_Diss", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "clay", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.3.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(1.5,2.7), ylim = c(1.5,2.7), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(As_RT.set.4.V3.pred, As.set.4[,"log10_As_RT"], col="darkgoldenrod",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(1.5,2.7, 0.5), labels=labelsX)
axis(2, at=seq(1.5,2.7, 0.5), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*As_RT.set.4.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*As_RT.set.4.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(As_RT.set.4.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.4.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.4.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[As_RT.set.4.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "As_AscCit", xpd=T)
text(lim[1]+(lim[2]-lim[1])*5/8, lim[4]-0.1*(lim[4]-lim[3]), labels = "S_Diss", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "clay", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(As_RT.set.4.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))
#--------------------------------------------------------------
dev.off()


#Parameters sets for grain Cd models
#-------------------------------------------------------------------------------------------------------------------------

Cd.data <- survey

resp_var <- c("Cd_RT")

Cd.set.1_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",   "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "Cd_ST")
Cd.set.2_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "P_DSE",    "S_DSE",
  "Mn_DSE",    "Co_DSE",   "Ni_DSE",   "Cu_DSE",   "Zn_DSE", 
  "Cd_DSE")
Cd.set.3_var <- c(
  "pH_m",     "pH_d",    "WC",      "TOC",     "clay",    "sand",      
  "Mg_SE",    "Si_SE",   "S_SE",    "K_SE",
  "Mn_SE",    "Fe_SE",   "Zn_SE",  
  "Cd_SE")
Cd.set.4_var <- c(
  "pH_m",     "pH_d",    "WC",      "TOC",     "clay",    "sand",  
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",   "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "Cd_ST",
  "P_DSE",    "S_DSE",
  "Mn_DSE",    "Co_DSE",   "Ni_DSE",   "Cu_DSE",   "Zn_DSE",
  "Cd_DSE",
  "Mg_SE",    "Si_SE",   "S_SE",    "K_SE",
  "Mn_SE",    "Fe_SE",   "Zn_SE", 
  "Cd_SE")
#--------------------------------------------------------------

#fitting best models
#--------------------------------------------------------------
#set.1
Cd.set.1 <- Cd.data[, c(resp_var,Cd.set.1_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

Cd.set.1[, !(colnames(Cd.set.1) %in% exclude_from_log10)] <- log10(Cd.set.1[, !(colnames(Cd.set.1) %in% exclude_from_log10)])

colnames(Cd.set.1)[!colnames(Cd.set.1) %in% exclude_from_log10] <- paste("log10_", colnames(Cd.set.1[, !(colnames(Cd.set.1) %in% exclude_from_log10)]), sep = "")

set.seed(1)

Cd.set.1[Cd.set.1 == "-Inf"] <- NA
Cd.set.1[Cd.set.1 == "NaN"] <- NA

Cd_RT.set.1.V1.BM <- regr(log10_Cd_RT ~ log10_Cd_ST, Cd.set.1, robust = T)
Cd_RT.set.1.V1.pred <- predict(Cd_RT.set.1.V1.BM, newdata = Cd.set.1)

Cd_RT.set.1.V2.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_ST + pH_d, mod_data = Cd.set.1, rob = T, rela = T)
Cd_RT.set.1.V2.pred <- predict(Cd_RT.set.1.V2.BM$model, newdata = Cd.set.1)

Cd_RT.set.1.V3.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_ST + pH_d + log10_Mg_ST, mod_data = Cd.set.1, rob = T, rela = T)
Cd_RT.set.1.V3.pred <- predict(Cd_RT.set.1.V3.BM$model, newdata = Cd.set.1)

#set.2
Cd.set.2 <- Cd.data[, c(resp_var,Cd.set.2_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

Cd.set.2[, !(colnames(Cd.set.2) %in% exclude_from_log10)] <- log10(Cd.set.2[, !(colnames(Cd.set.2) %in% exclude_from_log10)])

colnames(Cd.set.2)[!colnames(Cd.set.2) %in% exclude_from_log10] <- paste("log10_", colnames(Cd.set.2[, !(colnames(Cd.set.2) %in% exclude_from_log10)]), sep = "")

set.seed(1)

Cd.set.2[Cd.set.2 == "-Inf"] <- NA
Cd.set.2[Cd.set.2 == "NaN"] <- NA

Cd_RT.set.2.V1.BM <- regr(log10_Cd_RT ~ log10_Cd_DSE, Cd.set.2, robust = T)
Cd_RT.set.2.V1.pred <- predict(Cd_RT.set.2.V1.BM, newdata = Cd.set.2)

Cd_RT.set.2.V2.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_DSE + log10_Zn_DSE, mod_data = Cd.set.2, rob = T, rela = T)
Cd_RT.set.2.V2.pred <- predict(Cd_RT.set.2.V2.BM$model, newdata = Cd.set.2)

Cd_RT.set.2.V3.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_DSE + log10_Zn_DSE + log10_Cu_DSE, mod_data = Cd.set.2, rob = T, rela = T)
Cd_RT.set.2.V3.pred <- predict(Cd_RT.set.2.V3.BM$model, newdata = Cd.set.2)

#set.3
Cd.set.3 <- Cd.data[, c(resp_var,Cd.set.3_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

Cd.set.3[, !(colnames(Cd.set.3) %in% exclude_from_log10)] <- log10(Cd.set.3[, !(colnames(Cd.set.3) %in% exclude_from_log10)])

colnames(Cd.set.3)[!colnames(Cd.set.3) %in% exclude_from_log10] <- paste("log10_", colnames(Cd.set.3[, !(colnames(Cd.set.3) %in% exclude_from_log10)]), sep = "")

set.seed(1)

Cd.set.3[Cd.set.3 == "-Inf"] <- NA
Cd.set.3[Cd.set.3 == "NaN"] <- NA

Cd_RT.set.3.V1.BM <- regr(log10_Cd_RT ~ log10_Cd_SE, Cd.set.3, robust = T)
Cd_RT.set.3.V1.pred <- predict(Cd_RT.set.3.V1.BM, newdata = Cd.set.3)

Cd_RT.set.3.V2.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_SE + log10_Fe_SE, mod_data = Cd.set.3, rob = T, rela = T)
Cd_RT.set.3.V2.pred <- predict(Cd_RT.set.3.V2.BM$model, newdata = Cd.set.3)

Cd_RT.set.3.V3.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_SE + log10_Fe_SE + pH_m, mod_data = Cd.set.3, rob = T, rela = T)
Cd_RT.set.3.V3.pred <- predict(Cd_RT.set.3.V3.BM$model, newdata = Cd.set.3)

#set.4
Cd.set.4 <- Cd.data[, c(resp_var,Cd.set.4_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

Cd.set.4[, !(colnames(Cd.set.4) %in% exclude_from_log10)] <- log10(Cd.set.4[, !(colnames(Cd.set.4) %in% exclude_from_log10)])

colnames(Cd.set.4)[!colnames(Cd.set.4) %in% exclude_from_log10] <- paste("log10_", colnames(Cd.set.4[, !(colnames(Cd.set.4) %in% exclude_from_log10)]), sep = "")

set.seed(1)

Cd.set.4[Cd.set.4 == "-Inf"] <- NA
Cd.set.4[Cd.set.4 == "NaN"] <- NA

Cd_RT.set.4.V1.BM <- regr(log10_Cd_RT ~ log10_Cd_SE, Cd.set.4, robust = T)
Cd_RT.set.4.V1.pred <- predict(Cd_RT.set.4.V1.BM, newdata = Cd.set.4)

Cd_RT.set.4.V2.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_SE + log10_Fe_SE, mod_data = Cd.set.4, rob = T, rela = T)
Cd_RT.set.4.V2.pred <- predict(Cd_RT.set.4.V2.BM$model, newdata = Cd.set.4)

Cd_RT.set.4.V3.BM <- calcLMG(mod_form = log10_Cd_RT ~ log10_Cd_DSE + log10_Fe_SE + log10_Zn_DSE, mod_data = Cd.set.4, rob = T, rela = T)
Cd_RT.set.4.V3.pred <- predict(Cd_RT.set.4.V3.BM$model, newdata = Cd.set.4)
#--------------------------------------------------------------

#plot best Cd models: 4 sets of 1,2,3-variable models
pdf("Figure 3 (main part)_best grain Cd models.pdf", 8, 6)
par(mfrow=c(3,4), mar=c(2.5,2.5,2,1))
#--------------------------------------------------------------
labelsX=parse(text=paste(10, "^", seq(0,4, 1),sep=""))
labelsY=labelsX
orange.scale <- colorRampPalette( c( "white","orange" ))(100)
green.scale <- colorRampPalette( c( "white","darkgreen" ))(100)
#--------------------------------------------------------------
#V1
#--------------------------------------------------------------
plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.1.V1.pred, Cd.set.1[,"log10_Cd_RT"], col="black", 
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(Cd_RT.set.1.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_ST", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.1.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.2.V1.pred, Cd.set.2[,"log10_Cd_RT"], col="brown", 
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(Cd_RT.set.2.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_DSE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.2.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.3.V1.pred, Cd.set.3[,"log10_Cd_RT"], col="darkblue", 
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(Cd_RT.set.3.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_SE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.3.V1.BM$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.4.V1.pred, Cd.set.4[,"log10_Cd_RT"], col="darkgoldenrod", 
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
segments((lim[1]+lim[2])/2, lim[4], (lim[1]+lim[2])/2, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- list(green.scale,orange.scale)[[as.numeric(Cd_RT.set.4.V1.BM$coefficients[-1]<0)+1]]
rect(lim[1], lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), col=col.scale[100], border ="black", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_SE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.4.V1.BM$adj.r.squared, digits=1, nsmall=2))))
#--------------------------------------------------------------
#V2 
#--------------------------------------------------------------
plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.1.V2.pred, Cd.set.1[,"log10_Cd_RT"], col="black", 
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.1.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.1.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.1.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.1.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_ST", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "pH_d", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.1.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.2.V2.pred, Cd.set.2[,"log10_Cd_RT"],col="brown",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.2.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.2.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.2.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.2.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_DSE", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Zn_DSE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.2.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.3.V2.pred, Cd.set.3[,"log10_Cd_RT"],col="darkblue",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.3.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.3.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.3.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.3.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_SE", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Fe_SE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.3.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.4.V2.pred, Cd.set.4[,"log10_Cd_RT"],col="darkgoldenrod",
       pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.4.V2.BM$lmgs[1]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[2])/2, lim[4], lim[2]-(lim[2]-lim[1])/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.4.V2.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.4.V2.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.4.V2.BM$lmgs[2],2], border ="black", xpd=T)
text(lim[1]+(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_SE", xpd=T)
text(lim[2]-(lim[2]-lim[1])/4, lim[4]-0.1*(lim[4]-lim[3]), labels = "Fe_SE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.4.V2.BM$model$adj.r.squared, digits=1, nsmall=2))))
#--------------------------------------------------------------
#V3
#--------------------------------------------------------------
plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.1.V3.pred, Cd.set.1[,"log10_Cd_RT"], col="black",
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.1.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*Cd_RT.set.1.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], (lim[1]+lim[2])*2/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.1.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.1.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.1.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.1.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_ST", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "pH_d", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Mg_ST", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.1.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.2.V3.pred, Cd.set.2[,"log10_Cd_RT"],col="brown",
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.2.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*Cd_RT.set.2.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], (lim[1]+lim[2])*2/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.2.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.2.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.2.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.2.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_DSE", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Zn_DSE", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Cu_DSE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.2.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.3.V3.pred, Cd.set.3[,"log10_Cd_RT"],col="darkblue",
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.3.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*Cd_RT.set.3.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], (lim[1]+lim[2])*2/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.3.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.3.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.3.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.3.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_SE", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Fe_SE", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "pH_m", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.3.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))

plot(NA, xlim = c(0.5,4.5), ylim = c(0.5,4.5), xaxt = "n", yaxt = "n", 
     xlab = NA, ylab = NA)
abline(a=0,b=1, col="gray", lty=3)
lim <- par("usr")
points(Cd_RT.set.4.V3.pred, Cd.set.4[,"log10_Cd_RT"],col="darkgoldenrod",
     pch=21, bg="gray80", lwd=2, cex=1.5)
axis(1, at=seq(0,4,1), labels=labelsX)
axis(2, at=seq(0,4,1), labels=labelsY)
xlab.1 <- (lim[2]-lim[1])*Cd_RT.set.4.V3.BM$lmgs[1]/100
xlab.2 <- xlab.1+(lim[2]-lim[1])*Cd_RT.set.4.V3.BM$lmgs[2]/100
segments(lim[1]+xlab.1/2, lim[4], lim[1]+(lim[2]-lim[1])*1/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.1+lim[1]+xlab.2)/2, lim[4], (lim[1]+lim[2])*2/4, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
segments((lim[1]+xlab.2+lim[2])/2, lim[4], lim[1]+(lim[2]-lim[1])*7/8, lim[4]-0.04*(lim[4]-lim[3]),
         col = "gray80")
col.scale <- sapply(as.numeric(Cd_RT.set.4.V3.BM$model$coefficients[-1]<0)+1, 
                    function(i){list(green.scale,orange.scale)[[i]]})
rect(lim[1], lim[4], lim[1]+xlab.1, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.4.V3.BM$lmgs[1],1], border ="black", xpd=T)
rect(lim[1]+xlab.1, lim[4], lim[1]+xlab.2, lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.4.V3.BM$lmgs[2],2], border ="black", xpd=T)
rect(lim[1]+xlab.2, lim[4], lim[2], lim[4]+0.14*(lim[4]-lim[3]), 
     col=col.scale[Cd_RT.set.4.V3.BM$lmgs[3],3], border ="black", xpd=T)
text(adj=c(0,0.5), lim[1]+0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Cd_DSE", xpd=T)
text((lim[1]+lim[2])/2, lim[4]-0.1*(lim[4]-lim[3]), labels = "Fe_SE", xpd=T)
text(adj=c(1,0.5), lim[2]-0.05*(lim[2]-lim[1]), lim[4]-0.1*(lim[4]-lim[3]), labels = "Zn_DSE", xpd=T)
text(lim[2]-0.05*(lim[2]-lim[1]), lim[3]+0.05*(lim[4]-lim[3]), adj = c(1,0), 
     labels = substitute(paste("R"[adj]^2,"=",v), 
                         list(v=format(Cd_RT.set.4.V3.BM$model$adj.r.squared, digits=1, nsmall=2))))
#-------------------------------------------------------------------------------------------------------------------------
dev.off()


#legend
#--------------------------------------------------------------
image(0:100, y=1, z=as.matrix(0:100), col=orange.scale, yaxt = "n", xaxt = "n", bty="n")
axis(1, at=seq(0,100,20), labels=seq(0,100,20))
#rect(par("usr")[1],par("usr")[3],par("usr")[2],par("usr")[4], border = "black")
image(0:100, y=1, z=as.matrix(0:100), col=green.scale, yaxt = "n", xaxt = "n", bty="n")
axis(1, at=seq(0,100,20), labels=seq(0,100,20))
#--------------------------------------------------------------

#prepare for Figure S1: group soil according to pH
#-------------------------------------------------------------------------------------------------------------------------
#pH<=5.5 A; 5.5<pH<=6.5 B; 6.5<pH<=7.5 C; pH>7.5 D
survey[,"pH_level"] <- NA
survey[survey[,"pH_d"]<=5.5,"pH_level"] <- "A"
survey[(survey[,"pH_d"]>5.5)&(survey[,"pH_d"]<=6.5),"pH_level"] <- "B"
survey[(survey[,"pH_d"]>6.5)&(survey[,"pH_d"]<=7.5),"pH_level"] <- "C"
survey[survey[,"pH_d"]>7.5,"pH_level"] <- "D"

#0-1 no; 1-2 slight; 2-3 light; 3-5 medium; 5 heavy
survey[,"Cd_level"] <- NA
survey[,"As_level"] <- NA

soil.A <- survey[survey[,"pH_level"]=="A",]
soil.B <- survey[survey[,"pH_level"]=="B",]
soil.C <- survey[survey[,"pH_level"]=="C",]
soil.D <- survey[survey[,"pH_level"]=="D",]

#Cd levels, standard 2018
soil.A[soil.A[,"Cd_ST"]<0.3,"Cd_level"] <- "no"
soil.B[soil.B[,"Cd_ST"]<0.4,"Cd_level"] <- "no"
soil.C[soil.C[,"Cd_ST"]<0.6,"Cd_level"] <- "no"
soil.D[soil.D[,"Cd_ST"]<0.8,"Cd_level"] <- "no"

soil.A[(soil.A[,"Cd_ST"]>=0.3)&(soil.A[,"Cd_ST"]<0.6),"Cd_level"] <- "slight"
soil.B[(soil.B[,"Cd_ST"]>=0.4)&(soil.B[,"Cd_ST"]<0.8),"Cd_level"] <- "slight"
soil.C[(soil.C[,"Cd_ST"]>=0.6)&(soil.C[,"Cd_ST"]<1.2),"Cd_level"] <- "slight"
soil.D[(soil.D[,"Cd_ST"]>=0.8)&(soil.D[,"Cd_ST"]<1.6),"Cd_level"] <- "slight"

soil.A[(soil.A[,"Cd_ST"]>=0.6)&(soil.A[,"Cd_ST"]<0.9),"Cd_level"] <- "light"
soil.B[(soil.B[,"Cd_ST"]>=0.8)&(soil.B[,"Cd_ST"]<1.2),"Cd_level"] <- "light"
soil.C[(soil.C[,"Cd_ST"]>=1.2)&(soil.C[,"Cd_ST"]<1.8),"Cd_level"] <- "light"
soil.D[(soil.D[,"Cd_ST"]>=1.6)&(soil.D[,"Cd_ST"]<2.4),"Cd_level"] <- "light"

soil.A[(soil.A[,"Cd_ST"]>=0.9)&(soil.A[,"Cd_ST"]<1.5),"Cd_level"] <- "medium"
soil.B[(soil.B[,"Cd_ST"]>=1.2)&(soil.B[,"Cd_ST"]<2.0),"Cd_level"] <- "medium"
soil.C[(soil.C[,"Cd_ST"]>=1.8)&(soil.C[,"Cd_ST"]<3.0),"Cd_level"] <- "medium"
soil.D[(soil.D[,"Cd_ST"]>=2.4)&(soil.D[,"Cd_ST"]<4.0),"Cd_level"] <- "medium"

soil.A[soil.A[,"Cd_ST"]>=1.5,"Cd_level"] <- "heavy"
soil.B[soil.B[,"Cd_ST"]>=2.0,"Cd_level"] <- "heavy"
soil.C[soil.C[,"Cd_ST"]>=3.0,"Cd_level"] <- "heavy"
soil.D[soil.D[,"Cd_ST"]>=4.0,"Cd_level"] <- "heavy"


#As levels, standard 2018
soil.A[soil.A[,"As_ST"]<30,"As_level"] <- "no"
soil.B[soil.B[,"As_ST"]<30,"As_level"] <- "no"
soil.C[soil.C[,"As_ST"]<25,"As_level"] <- "no"
soil.D[soil.D[,"As_ST"]<20,"As_level"] <- "no"

soil.A[(soil.A[,"As_ST"]>=30)&(soil.A[,"As_ST"]<60),"As_level"] <- "slight"
soil.B[(soil.B[,"As_ST"]>=30)&(soil.B[,"As_ST"]<60),"As_level"] <- "slight"
soil.C[(soil.C[,"As_ST"]>=25)&(soil.C[,"As_ST"]<50),"As_level"] <- "slight"
soil.D[(soil.D[,"As_ST"]>=20)&(soil.D[,"As_ST"]<40),"As_level"] <- "slight"

soil.A[(soil.A[,"As_ST"]>=60)&(soil.A[,"As_ST"]<90),"As_level"] <- "light"
soil.B[(soil.B[,"As_ST"]>=60)&(soil.B[,"As_ST"]<90),"As_level"] <- "light"
soil.C[(soil.C[,"As_ST"]>=50)&(soil.C[,"As_ST"]<75),"As_level"] <- "light"
soil.D[(soil.D[,"As_ST"]>=40)&(soil.D[,"As_ST"]<60),"As_level"] <- "light"

soil.A[(soil.A[,"As_ST"]>=90)&(soil.A[,"As_ST"]<150),"As_level"] <- "medium"
soil.B[(soil.B[,"As_ST"]>=90)&(soil.B[,"As_ST"]<150),"As_level"] <- "medium"
soil.C[(soil.C[,"As_ST"]>=75)&(soil.C[,"As_ST"]<125),"As_level"] <- "medium"
soil.D[(soil.D[,"As_ST"]>=60)&(soil.D[,"As_ST"]<100),"As_level"] <- "medium"

soil.A[soil.A[,"As_ST"]>=150,"As_level"] <- "heavy"
soil.B[soil.B[,"As_ST"]>=150,"As_level"] <- "heavy"
soil.C[soil.C[,"As_ST"]>=125,"As_level"] <- "heavy"
soil.D[soil.D[,"As_ST"]>=100,"As_level"] <- "heavy"

#give As and Cd levels to samples
survey[survey[,"pH_level"]=="A","Cd_level"] <- soil.A[,"Cd_level"]
survey[survey[,"pH_level"]=="B","Cd_level"] <- soil.B[,"Cd_level"]
survey[survey[,"pH_level"]=="C","Cd_level"] <- soil.C[,"Cd_level"]
survey[survey[,"pH_level"]=="D","Cd_level"] <- soil.D[,"Cd_level"]

survey[survey[,"pH_level"]=="A","As_level"] <- soil.A[,"As_level"]
survey[survey[,"pH_level"]=="B","As_level"] <- soil.B[,"As_level"]
survey[survey[,"pH_level"]=="C","As_level"] <- soil.C[,"As_level"]
survey[survey[,"pH_level"]=="D","As_level"] <- soil.D[,"As_level"]

color.selection <- c("coral","gold","darkolivegreen3","skyblue")
co <- colourmap(color.selection, breaks=c(3, 5.5, 6.5, 7.5, 8))
#-------------------------------------------------------------------------------------------------------------------------


#pdf("Figure S1_soil and rice contamination.pdf",8,6)
png("Figure S1_soil and rice contamination.png",8,6, units = "in", res = 300)
#-------------------------------------------------------------------------------------------------------------------------
par(mfrow=c(1,2), mar=c(5,4,1,1))
#plot As
survey[,"iAs"] <-(survey[,"As_RT"]-survey[,"DMA"]) 
stripchart(iAs~As_level, at=c(5,3,4,1,2), data=survey, vertical=TRUE, pch=21, cex.lab=1.2, font.lab=2,
           ylim=c(0,300),
           ylab="Inorganic As in brown rice (µg/kg)", xlab="Soil As contamination level")
#abline(h=0, col="gray80", lty=1)
abline(h=200, col="red", lty=2)
points(x=rep(1,times=nrow(survey[survey[,"As_level"]=="no",])),
       y=survey[survey[,"As_level"]=="no","iAs"],
       cex=1.2, pch=21, bg = co(survey[survey[,"As_level"]=="no","pH_d"]))
points(x=rep(2,times=nrow(survey[survey[,"As_level"]=="slight",])),
       y=survey[survey[,"As_level"]=="slight","iAs"],
       cex=1.2, pch=21, bg = co(survey[survey[,"As_level"]=="slight","pH_d"]))
points(x=rep(3,times=nrow(survey[survey[,"As_level"]=="light",])),
       y=survey[survey[,"As_level"]=="light","iAs"],
       cex=1.2, pch=21, bg = co(survey[survey[,"As_level"]=="light","pH_d"]))
points(x=rep(4,times=nrow(survey[survey[,"As_level"]=="medium",])),
       y=survey[survey[,"As_level"]=="medium","iAs"],
       cex=1.2, pch=21, bg = co(survey[survey[,"As_level"]=="medium","pH_d"]))
points(x=rep(5,times=nrow(survey[survey[,"As_level"]=="heavy",])),
       y=survey[survey[,"As_level"]=="heavy","iAs"],
       cex=1.2, pch=21, bg = co(survey[survey[,"As_level"]=="heavy","pH_d"]))
legend("bottomright",legend = c("< 5.5","5.5 ~ 6.5","6.5 ~ 7.5","> 7.5"), title=expression(bold("Soil pH (dry)")),
       pch=21, pt.cex=1.2, pt.bg = color.selection, text.font = 2)

#plot Cd
stripchart(Cd_RT~Cd_level, at=c(5,3,4,1,2), data=survey, vertical=TRUE, pch=21, cex.lab=1.2, font.lab=2,
           ylim=c(0,4000),
           ylab="Cd in brown rice (µg/kg)", xlab="Soil Cd contamination level")
abline(h=200, col="red", lty=2)
points(x=rep(1,times=nrow(survey[survey[,"Cd_level"]=="no",])),
       y=survey[survey[,"Cd_level"]=="no","Cd_RT"],
       cex=1.2, pch=21, bg=co(survey[survey[,"Cd_level"]=="no","pH_d"]))
points(x=rep(2,times=nrow(survey[survey[,"Cd_level"]=="slight",])),
       y=survey[survey[,"Cd_level"]=="slight","Cd_RT"],
       cex=1.2, pch=21, bg=co(survey[survey[,"Cd_level"]=="slight","pH_d"]))
points(x=rep(3,times=nrow(survey[survey[,"Cd_level"]=="light",])),
       y=survey[survey[,"Cd_level"]=="light","Cd_RT"],
       cex=1.2, pch=21, bg=co(survey[survey[,"Cd_level"]=="light","pH_d"]))
points(x=rep(4,times=nrow(survey[survey[,"Cd_level"]=="medium",])),
       y=survey[survey[,"Cd_level"]=="medium","Cd_RT"],
       cex=1.2, pch=21, bg=co(survey[survey[,"Cd_level"]=="medium","pH_d"]))
points(x=rep(5,times=nrow(survey[survey[,"Cd_level"]=="heavy",])),
       y=survey[survey[,"Cd_level"]=="heavy","Cd_RT"],
       cex=1.2, pch=21, bg=co(survey[survey[,"Cd_level"]=="heavy","pH_d"]))

#-------------------------------------------------------------------------------------------------------------------------
dev.off()

#check correlation among variables
pdf("Figure S2_correlation matrix for As.pdf", width = 8, height = 8)
#--------------------------------------------------------------
#for less variables: correlation matrix after log transformation
As_RT_corr <- survey[, c("As_RT","pH_m","pH_d","WC",
                         "TOC","OC_Diss", 
                         "clay","sand",
                         "Cu_ST",
                         "As_ST","As_AscCit","As_Diss",
                         "Fe_ST","Fe_AscCit","Fe_Diss",
                         "Mn_ST","Mn_AscCit","Mn_Diss",
                         "S_ST","S_AscCit","S_Diss",
                         "Si_Diss")] 
exclude_from_log10 <- c("pH_m","pH_d")
As_RT_corr[, !(colnames(As_RT_corr) %in% exclude_from_log10)] <- log10(As_RT_corr[, !(colnames(As_RT_corr) %in% exclude_from_log10)])
As_RT_corr[As_RT_corr == "-Inf"] <- NA
As_RT_corr[As_RT_corr == "NaN"] <- NA

cor.matrix.lg <- format(round(cor(As_RT_corr, method = "pearson", use = "pairwise.complete.obs"), digits=3), 
                        digits = 1, nsmall = 3)
class(cor.matrix.lg) <- "numeric"
ggcorrplot(cor.matrix.lg, hc.order = F, type = "lower", outline.col = "white", 
           ggtheme = ggplot2::theme_gray, colors = c("#6D9EC1", "white", "#E46726"), 
           digits = 2, lab = T, lab_size = 2.8, tl.cex = 10)#the bug on displaced digits was reported and may be fixed later
#--------------------------------------------------------------
dev.off()

pdf("Figure S3_correlation matrix for Cd.pdf", width = 8, height = 8)
#--------------------------------------------------------------
Cd_RT_corr <- survey[, c("Cd_RT","pH_m","pH_d","WC","TOC","clay","sand",
                         "Cd_ST","Cd_SE","Cd_DSE",
                         "Fe_ST","Fe_SE","Fe_DSE",
                         "Mn_ST","Mn_SE","Mn_DSE",
                         "S_ST","S_SE","S_DSE","Si_SE",
                         "Zn_ST","Zn_SE","Zn_DSE")] 
exclude_from_log10 <- c("pH_m","pH_d")
Cd_RT_corr[, !(colnames(Cd_RT_corr) %in% exclude_from_log10)] <- log10(Cd_RT_corr[, !(colnames(Cd_RT_corr) %in% exclude_from_log10)])
Cd_RT_corr[Cd_RT_corr == "-Inf"] <- NA
Cd_RT_corr[Cd_RT_corr == "NaN"] <- NA

cor.matrix.lg <- format(round(cor(Cd_RT_corr, method = "pearson", use = "pairwise.complete.obs"), digits=3), 
                        digits = 1, nsmall = 3)
class(cor.matrix.lg) <- "numeric"
ggcorrplot(cor.matrix.lg, hc.order = F, type = "lower", outline.col = "white", 
           ggtheme = ggplot2::theme_gray, colors = c("#6D9EC1", "white", "#E46726"), 
           digits = 2, lab = T, lab_size = 2.8, tl.cex = 10)#the bug on displaced digits was reported and may be fixed later
#--------------------------------------------------------------
dev.off()


#pdf("Figure S4_Texture triangle_USDA.pdf", width = 8, height = 8)
png("Figure S4_Texture triangle_USDA.png", width = 8, height = 8, units = "in",res = 300)
#--------------------------------------------------------------
texture <- survey[,c("clay","silt","sand")]
colnames(texture) <- c("CLAY","SILT","SAND")

par(mfrow=c(1,1))
TT.plot(class.sys = "USDA.TT", tri.data = texture, tri.sum.tst=F,
        cex.axis = 0.8, cex.lab = 0.8, lwd.axis = 1, lwd.lab = 1,
        cex=1, pch=19, col = co(survey[,"pH_d"]))
lim <- par("usr")
legend(x=100, y=88, xjust = 1, yjust = 1, bty = "n",
       legend = c("< 5.5","5.5 ~ 6.5","6.5 ~ 7.5","> 7.5"), title=expression(bold("Soil pH (dry)")),
       pch=19, pt.cex=1, col = color.selection, text.font = 2)

#--------------------------------------------------------------
dev.off()




