#Load packages:  regr0  parallel

#install packages
install.packages("quantreg")
install.packages("leaps")
install.packages("regr0", repos="http://R-Forge.R-project.org")

library("robustbase")
library("parallel")
library("quantreg")
library("leaps")
library("regr0")

#load functions by open and run:
#bestmodels_R2CV.R   
#bestmodels_R2CV_details.R   
#calcLMG (by Michael Simmler).R

survey <- read.table("field survey_data.csv",header=TRUE,sep=",", skip=2)  

As.data <- survey

#-------------------------------------------------------------------------------------------------------------------------

resp_var <- c("As_RT")

set.1_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",    "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "As_ST"
  )#n = 4 + 12 = 16

set.2_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Al_AscCit",    "P_AscCit",    "S_AscCit",
  "Mn_AscCit",    "Fe_AscCit",   "Co_AscCit",   "Ni_AscCit",    "Cu_AscCit",
  "As_AscCit"
  )#n = 4 + 9 =13

set.3_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "OC_Diss",    "N_Diss",    "Al_Diss",    "Si_Diss",   "P_Diss",    "S_Diss",
  "Mn_Diss",    "Fe_Diss",   "Co_Diss",    "Ni_Diss",    
  "As_Diss"
  )#n = 4 + 11 = 15

set.4_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",    "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "As_ST", 
  "Al_AscCit",    "P_AscCit",    "S_AscCit",
  "Mn_AscCit",    "Fe_AscCit",   "Co_AscCit",   "Ni_AscCit",    "Cu_AscCit",
  "As_AscCit",
  "OC_Diss",    "N_Diss",    "Al_Diss",    "Si_Diss",   "P_Diss",    "S_Diss",
  "Mn_Diss",    "Fe_Diss",   "Co_Diss",    "Ni_Diss",    
  "As_Diss"
)  
#-------------------------------------------------------------------------------------------------------------------------

#let's model it!
#set.1
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- As.data[, c(resp_var,set.1_var)] 
exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)
#adj.r.squared and cv_rmse cross checked models 
time.0 <- Sys.time()
R2CV.models_1var.As_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.As_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.As_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.As_RT.V1.S1 <- BM.R2CV.details(regression_data, R2CV.models_1var.As_RT)
details.As_RT.V2.S1 <- BM.R2CV.details(regression_data, R2CV.models_2var.As_RT, 10)
details.As_RT.V3.S1 <- BM.R2CV.details(regression_data, R2CV.models_3var.As_RT, 10)

write.csv(details.As_RT.V1.S1, file = "As_RT.V1.S1.csv")
write.csv(details.As_RT.V2.S1, file = "As_RT.V2.S1.csv")
write.csv(details.As_RT.V3.S1, file = "As_RT.V3.S1.csv")
#-------------------------------------------------------------------------------------------------------------------------

#set.2
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- As.data[, c(resp_var,set.2_var)] 
exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)
#adj.r.squared and cv_rmse cross checked models 
time.0 <- Sys.time()
R2CV.models_1var.As_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.As_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.As_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.As_RT.V1.S2 <- BM.R2CV.details(regression_data, R2CV.models_1var.As_RT)
details.As_RT.V2.S2 <- BM.R2CV.details(regression_data, R2CV.models_2var.As_RT, 10)
details.As_RT.V3.S2 <- BM.R2CV.details(regression_data, R2CV.models_3var.As_RT, 10)

time.1-time.0# mins
time.2-time.1# mins
time.3-time.2# mins

write.csv(details.As_RT.V1.S2, file = "As_RT.V1.S2.csv")
write.csv(details.As_RT.V2.S2, file = "As_RT.V2.S2.csv")
write.csv(details.As_RT.V3.S2, file = "As_RT.V3.S2.csv")

#-------------------------------------------------------------------------------------------------------------------------

#set.3
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- As.data[, c(resp_var,set.3_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)
#adj.r.squared and cv_rmse cross checked models 
time.0 <- Sys.time()
R2CV.models_1var.As_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.As_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.As_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.As_RT.V1.S3 <- BM.R2CV.details(regression_data, R2CV.models_1var.As_RT)
details.As_RT.V2.S3 <- BM.R2CV.details(regression_data, R2CV.models_2var.As_RT, 10)
details.As_RT.V3.S3 <- BM.R2CV.details(regression_data, R2CV.models_3var.As_RT, 10)

write.csv(details.As_RT.V1.S3, file = "As_RT.V1.S3.csv")
write.csv(details.As_RT.V2.S3, file = "As_RT.V2.S3.csv")
write.csv(details.As_RT.V3.S3, file = "As_RT.V3.S3.csv")

#-------------------------------------------------------------------------------------------------------------------------

#set.4
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- As.data[, c(resp_var,set.4_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA

regression_data <- round(regression_data,digits = 6)

set.seed(1)
#adj.r.squared and cv_rmse cross checked models 
time.0 <- Sys.time()
R2CV.models_1var.As_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.As_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.As_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.As_RT.V1.S4 <- BM.R2CV.details(regression_data, R2CV.models_1var.As_RT)
details.As_RT.V2.S4 <- BM.R2CV.details(regression_data, R2CV.models_2var.As_RT, 10)
details.As_RT.V3.S4 <- BM.R2CV.details(regression_data, R2CV.models_3var.As_RT, 10)

write.csv(details.As_RT.V1.S4, file = "As_RT.V1.S4.csv")
write.csv(details.As_RT.V2.S4, file = "As_RT.V2.S4.csv")
write.csv(details.As_RT.V3.S4, file = "As_RT.V3.S4.csv")

#-------------------------------------------------------------------------------------------------------------------------


