# Load packages, functions, and prepare the data 

#install packages
#make sure run As models first, or delele "#" before line 5 to line 7!
#install.packages("quantreg")
#install.packages("leaps")
#install.packages("regr0", repos="http://R-Forge.R-project.org")

library("robustbase")
library("parallel")
library("quantreg")
library("leaps")
library("regr0")

#load functions by open and run:
#bestmodels_R2CV.R   
#bestmodels_R2CV_details.R   
#calcLMG (by Michael Simmler).R

survey <- read.table("field survey_data.csv",header=TRUE,sep=",", skip=2)  

Cd.data <- survey

#-------------------------------------------------------------------------------------------------------------------------
resp_var <- c("Cd_RT")

set.1_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "Mg_ST",    "P_ST",    "S_ST",    "K_ST",    "Ca_ST",
  "Mn_ST",    "Fe_ST",   "Co_ST",   "Ni_ST",   "Cu_ST",   "Zn_ST",
  "Cd_ST")
set.2_var <- c(
  "pH_d",     "TOC",     "clay",    "sand",      
  "P_DSE",    "S_DSE",
  "Mn_DSE",    "Co_DSE",   "Ni_DSE",   "Cu_DSE",   "Zn_DSE",
  "Cd_DSE")
set.3_var <- c(
  "WC",      
  "pH_m",     "pH_d",   "TOC",     "clay",    "sand",      
  "Mg_SE",    "Si_SE",   "S_SE",    "K_SE",
  "Mn_SE",    "Fe_SE",   "Zn_SE",
  "Cd_SE")
set.4_var <- c(
  "WC",       "pH_m",       "TOC",      
 "pH_d",   "clay",    "sand",  
 "Mg_ST",    "P_ST",  "K_ST",    "Ca_ST",    "Co_ST",   "Ni_ST",  
  "Mn_ST",    "Fe_ST",  "Cu_ST",  "S_ST",      "Zn_ST",
  "Cd_ST",
  "P_DSE",    "S_DSE",
  "Mn_DSE",    "Co_DSE",   "Ni_DSE",   "Cu_DSE",   "Zn_DSE",
  "Cd_DSE",
  "Mg_SE",    "Si_SE",   "K_SE",
  "Mn_SE",    "Fe_SE",   "Zn_SE",    "S_SE",
  "Cd_SE"
 )
#-------------------------------------------------------------------------------------------------------------------------

#let's model it!
#set.1
#-------------------------------------------------------------------------------------------------------------------------

regression_data <- Cd.data[, c(resp_var,set.1_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

set.seed(1)

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)

time.0 <- Sys.time()
R2CV.models_1var.Cd_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.Cd_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.Cd_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.Cd_RT.V1.S1 <- BM.R2CV.details(regression_data, R2CV.models_1var.Cd_RT)
details.Cd_RT.V2.S1 <- BM.R2CV.details(regression_data, R2CV.models_2var.Cd_RT, 10)
details.Cd_RT.V3.S1 <- BM.R2CV.details(regression_data, R2CV.models_3var.Cd_RT, 10)

write.csv(details.Cd_RT.V1.S1, file = "Cd_RT.V1.S1.csv")
write.csv(details.Cd_RT.V2.S1, file = "Cd_RT.V2.S1.csv")
write.csv(details.Cd_RT.V3.S1, file = "Cd_RT.V3.S1.csv")
#-------------------------------------------------------------------------------------------------------------------------

#set.2
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- Cd.data[, c(resp_var,set.2_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

set.seed(1)

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)

time.0 <- Sys.time()
R2CV.models_1var.Cd_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.Cd_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.Cd_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.Cd_RT.V1.S2 <- BM.R2CV.details(regression_data, R2CV.models_1var.Cd_RT)
details.Cd_RT.V2.S2 <- BM.R2CV.details(regression_data, R2CV.models_2var.Cd_RT, 10)
details.Cd_RT.V3.S2 <- BM.R2CV.details(regression_data, R2CV.models_3var.Cd_RT, 10)

write.csv(details.Cd_RT.V1.S2, file = "Cd_RT.V1.S2.csv")
write.csv(details.Cd_RT.V2.S2, file = "Cd_RT.V2.S2.csv")
write.csv(details.Cd_RT.V3.S2, file = "Cd_RT.V3.S2.csv")
#-------------------------------------------------------------------------------------------------------------------------

#set.3
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- Cd.data[, c(resp_var,set.3_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

set.seed(1)

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)

time.0 <- Sys.time()
R2CV.models_1var.Cd_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.Cd_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.Cd_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.Cd_RT.V1.S3 <- BM.R2CV.details(regression_data, R2CV.models_1var.Cd_RT)
details.Cd_RT.V2.S3 <- BM.R2CV.details(regression_data, R2CV.models_2var.Cd_RT, 10)
details.Cd_RT.V3.S3 <- BM.R2CV.details(regression_data, R2CV.models_3var.Cd_RT, 10)

write.csv(details.Cd_RT.V1.S3, file = "Cd_RT.V1.S3.csv")
write.csv(details.Cd_RT.V2.S3, file = "Cd_RT.V2.S3.csv")
write.csv(details.Cd_RT.V3.S3, file = "Cd_RT.V3.S3.csv")
#-------------------------------------------------------------------------------------------------------------------------

#set.4
#-------------------------------------------------------------------------------------------------------------------------
regression_data <- Cd.data[, c(resp_var,set.4_var)] 

exclude_from_log10 <- c("pH_m","pH_d")

regression_data[, !(colnames(regression_data) %in% exclude_from_log10)] <- log10(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)])

colnames(regression_data)[!colnames(regression_data) %in% exclude_from_log10] <- paste("log10_", colnames(regression_data[, !(colnames(regression_data) %in% exclude_from_log10)]), sep = "")

set.seed(1)

regression_data[regression_data == "-Inf"] <- NA
regression_data[regression_data == "NaN"] <- NA
regression_data <- round(regression_data,digits = 6)

set.seed(1)

time.0 <- Sys.time()
R2CV.models_1var.Cd_RT <- BM.R2CV(regression_data, mod_size=1, fold=5, repetitions=100, rob=T)
time.1 <- Sys.time()
R2CV.models_2var.Cd_RT <- BM.R2CV(regression_data, mod_size=2, fold=5, repetitions=100, rob=T)
time.2 <- Sys.time()
R2CV.models_3var.Cd_RT <- BM.R2CV(regression_data, mod_size=3, fold=5, repetitions=100, rob=T)
time.3 <- Sys.time()
difftime(c(time.1, time.2, time.3), c(time.0, time.1, time.2))

details.Cd_RT.V1.S4 <- BM.R2CV.details(regression_data, R2CV.models_1var.Cd_RT)
details.Cd_RT.V2.S4 <- BM.R2CV.details(regression_data, R2CV.models_2var.Cd_RT, 10)
details.Cd_RT.V3.S4 <- BM.R2CV.details(regression_data, R2CV.models_3var.Cd_RT, 10)

#write codes to export detailed results
write.csv(details.Cd_RT.V1.S4, file = "Cd_RT.V1.S4.csv")
write.csv(details.Cd_RT.V2.S4, file = "Cd_RT.V2.S4.csv")
write.csv(details.Cd_RT.V3.S4, file = "Cd_RT.V3.S4.csv")

#-------------------------------------------------------------------------------------------------------------------------





